==> process-optaplanner-springboot-1.4.1.Final-sources.jar: org/kie/kogito/examples/Flights_18_TaskInput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.examples;

import java.util.Map;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "approveDenyPassenger", processName = "flights")
public class Flights_18_TaskInput {

    private String _id;

    private String _name;

    public void setId(String id) {
        this._id = id;
    }

    public String getId() {
        return this._id;
    }

    public void setName(String name) {
        this._name = name;
    }

    public String getName() {
        return this._name;
    }

    public static Flights_18_TaskInput from(org.kie.kogito.process.WorkItem workItem) {
        Flights_18_TaskInput item = new Flights_18_TaskInput();
        item._id = workItem.getId();
        item._name = workItem.getName();
        Map<String, Object> params = workItem.getParameters();
        item.passenger = (org.kie.kogito.examples.domain.PassengerDTO) params.get("passenger");
        return item;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private org.kie.kogito.examples.domain.PassengerDTO passenger;

    public org.kie.kogito.examples.domain.PassengerDTO getPassenger() {
        return passenger;
    }

    public void setPassenger(org.kie.kogito.examples.domain.PassengerDTO passenger) {
        this.passenger = passenger;
    }
}
// Task input model for user task 'Approve/Deny Passenger' in process 'flights'

==> process-optaplanner-springboot-1.8.0.Final-sources.jar: org/kie/kogito/examples/Flights_18_TaskInput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.examples;

import java.util.Map;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "approveDenyPassenger", processName = "flights")
public class Flights_18_TaskInput {

    public static Flights_18_TaskInput fromMap(Map<String, Object> params) {
        Flights_18_TaskInput item = new Flights_18_TaskInput();
        item.passenger = (org.kie.kogito.examples.domain.PassengerDTO) params.get("passenger");
        return item;
    }

    @UserTaskParam(value = ParamType.INPUT)
    private org.kie.kogito.examples.domain.PassengerDTO passenger;

    public org.kie.kogito.examples.domain.PassengerDTO getPassenger() {
        return passenger;
    }

    public void setPassenger(org.kie.kogito.examples.domain.PassengerDTO passenger) {
        this.passenger = passenger;
    }
}
// Task input for user task 'Approve/Deny Passenger' in process 'flights'
